@@ -1,6 +1,6 @@
 /* Copyright (C) 2004 Morten K. Poulsen <morten at afdelingp.dk>
  *
- * $Id: mlmmj-bounce.c,v 1.35 2005/02/03 16:20:32 mmj Exp $
+ * $Id: mlmmj-bounce.c,v 1.38 2005/05/02 17:39:10 mmj Exp $
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to
@@ -302,12 +302,14 @@ int main(int argc, char **argv)
 
 	if(dsnbounce) {
 		address = dsnparseaddr(mailname);
-		if(address == NULL) {
-			/* not parseable, so unlink and clean up */
-			if(mailname)
-				unlink(mailname);
+
+		/* Delete the mailfile, no need for it anymore */
+		if(mailname)
+			unlink(mailname);
+
+		if(address == NULL)
 			exit(EXIT_SUCCESS);
-		}
+
 		a = strrchr(address, '@');
 		*a = '=';
 	}
@@ -338,12 +340,16 @@ int main(int argc, char **argv)
 		a = concatstr(3, listdir, "/subconf/", address);
 		unlink(a);
 		myfree(a);
+		if(mailname)
+			unlink(mailname);
 		exit(EXIT_SUCCESS);
 	}
 	if(strcmp(number, "confunsub") == 0) {
 		a = concatstr(3, listdir, "/unsubconf/", address);
 		unlink(a);
 		myfree(a);
+		if(mailname)
+			unlink(mailname);
 		exit(EXIT_SUCCESS);
 	}
 	/* Below checks for bounce probes bouncing. If they do, simply remove
@@ -362,12 +368,19 @@ int main(int argc, char **argv)
 	bfilename = concatstr(3, listdir, "/bounce/", address);
 
 	a = strrchr(address, '=');
-	if (!a)
+	if (!a) {
+		if(mailname)
+			unlink(mailname);
 		exit(EXIT_SUCCESS);  /* ignore malformed address */
+	}
 	*a = '@';
 
 	/* make sure it's a subscribed address */
 	if(is_subbed(listdir, address)) {
+		log_error(LOG_ARGS, "%s is bouncing but not subscribed?",
+				address);
+		if(mailname)
+			unlink(mailname);
 		myfree(bfilename);
 		exit(EXIT_SUCCESS); /* Not subbed, so exit silently */
 	}
