@@ -1,6 +1,6 @@
-/* Copyright (C) 2002, 2003, 2004 Mads Martin Joergensen <mmj at mmj.dk>
+/* Copyright (C) 2003, 2003, 2004 Mads Martin Joergensen <mmj at mmj.dk>
  *
- * $Id: mlmmj-process.c,v 1.66 2005/02/08 18:21:48 mmj Exp $
+ * $Id: mlmmj-process.c,v 1.68 2005/05/02 17:41:01 mmj Exp $
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to
@@ -419,6 +419,7 @@ int main(int argc, char **argv)
 	log_error(LOG_ARGS, "donemailname = [%s]\n", donemailname);
 #endif
 	if((rawmailfd = open(mailfile, O_RDONLY)) < 0) {
+		unlink(donemailname);
 		myfree(donemailname);
 		log_error(LOG_ARGS, "could not open() input mail file");
 		exit(EXIT_FAILURE);
@@ -473,18 +474,6 @@ int main(int argc, char **argv)
 		for(i = 0; i < readhdrs[0].valuecount; i++) {
 			find_email_adr(readhdrs[0].values[i], &fromemails);
 		}
-		if(fromemails.emailcount != 1) { /* discard malformed mail */
-			discardname = concatstr(3, listdir,
-						"/queue/discarded/",
-						randomstr);
-			rename(mailfile, discardname);
-			unlink(donemailname);
-			myfree(donemailname);
-			myfree(discardname);
-			myfree(randomstr);
-			/* TODO: free emailstructs */
-			exit(EXIT_SUCCESS);
-		}
 	}
 
 	if(readhdrs[1].token) { /* To: addresses */
@@ -584,6 +573,19 @@ int main(int argc, char **argv)
 		return EXIT_SUCCESS;
 	}
 
+	/* discard malformed mail with invalid From: */
+	if(fromemails.emailcount != 1) { 
+		discardname = concatstr(3, listdir,
+				"/queue/discarded/", randomstr);
+		rename(mailfile, discardname);
+		unlink(donemailname);
+		myfree(donemailname);
+		myfree(discardname);
+		myfree(randomstr);
+		/* TODO: free emailstructs */
+		exit(EXIT_SUCCESS);
+	}
+
 	myfree(delheaders);
 
 	if(efromemails.emailcount != 1) { /* don't send mails with <> in From
