@@ -1,6 +1,6 @@
 /* Copyright (C) 2004, 2003, 2004 Mads Martin Joergensen <mmj at mmj.dk>
  *
- * $Id: mlmmj-send.c,v 1.83 2005/05/04 09:37:54 mmj Exp $
+ * $Id: mlmmj-send.c,v 1.84 2005/06/20 12:40:39 mmj Exp $
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to
@@ -927,8 +927,13 @@ int main(int argc, char **argv)
 		if(sendres) {
 			/* error, so keep it in the queue */
 			deletewhensent = 0;
-			/* dump date we want when resending */
+			/* dump data we want when resending first check
+			 * if it already exists. In that case continue */
 			tmpstr = concatstr(2, mailfilename, ".mailfrom");
+			if(stat(tmpstr, &st) == 0) {
+				myfree(tmpstr);
+				break;
+			}
 			tmpfd = open(tmpstr, O_WRONLY|O_CREAT|O_TRUNC,
 						S_IRUSR|S_IWUSR);
 			myfree(tmpstr);
@@ -938,6 +943,10 @@ int main(int argc, char **argv)
 			}
 			close(tmpfd);
 			tmpstr = concatstr(2, mailfilename, ".reciptto");
+			if(stat(tmpstr, &st) == 0) {
+				myfree(tmpstr);
+				break;
+			}
 			tmpfd = open(tmpstr, O_WRONLY|O_CREAT|O_TRUNC,
 						S_IRUSR|S_IWUSR);
 			myfree(tmpstr);
@@ -949,6 +958,10 @@ int main(int argc, char **argv)
 			if(replyto) {
 				tmpstr = concatstr(2, mailfilename,
 						      ".reply-to");
+				if(stat(tmpstr, &st) == 0) {
+					myfree(tmpstr);
+					break;
+				}
 				tmpfd = open(tmpstr, O_WRONLY|O_CREAT|O_TRUNC,
 							S_IRUSR|S_IWUSR);
 				myfree(tmpstr);
